==> limnoria_2019.11.09.orig.tar.gz: limnoria-2019.11.09/README.md <==
Supybot is a robust (it doesn't crash), user friendly (it's easy to
configure) and programmer friendly (plugins are *extremely* easy to
write) Python IRC bot.  It aims to be an adequate replacement for most
existing IRC bots.  It includes a very flexible and powerful ACL system
for controlling access to commands, as well as more than 50 builtin plugins
providing around 400 actual commands.

Limnoria is the project which continues development of Supybot since 2010.

# Build status

Master branch: [![Build Status (master branch)](https://travis-ci.org/ProgVal/Limnoria.png?branch=master)](https://travis-ci.org/ProgVal/Limnoria)

Testing branch: [![Build Status (testing branch)](https://travis-ci.org/ProgVal/Limnoria.png?branch=testing)](https://travis-ci.org/ProgVal/Limnoria)

Limnoria supports CPython 2.6, 2.7, 3.2, 3.3, 3.4, 3.5, 3.6, nightly;
and Pypy 2 and 3. It works best with CPython 3.4 and higher.
Python 2.5 and older versions are not supported.

# Support

## Documentation

If this is your first install, there is an [install guide](http://doc.supybot.aperio.fr/en/latest/use/install.html).
You will probably be pointed to it if you ask on IRC how to install
Limnoria.
TL;DR version:

```
sudo apt-get install python3 python3-pip
pip3 install --user limnoria
supybot-wizard
```

There is extensive documentation at [doc.supybot.aperio.fr] and at
[Gribble wiki]. We took the time to write it; you should take the time to
read it.

[doc.supybot.aperio.fr]:http://doc.supybot.aperio.fr/
[Gribble wiki]:https://sourceforge.net/p/gribble/wiki/Main_Page/

## IRC channels

### In English

If you have any trouble, feel free to swing by [#supybot and #limnoria](ircs://chat.freenode.net:6697/#supybot,#limnoria) on
[freenode](https://freenode.net/) or [#supybot](ircs://irc.oftc.net:6697/#supybot) at [OFTC](http://oftc.net/) (we have a Limnoria there relaying,
so either network works) and ask questions.  We'll be happy to help
wherever we can.  And by all means, if you find anything hard to
understand or think you know of a better way to do something,
*please* post it on the [issue tracker] so we can improve the bot!

[issue tracker]:https://github.com/ProgVal/Limnoria/issues

### In Other languages

Only in French at the moment, located at [#supybot-fr on freenode](ircs://chat.freenode.net:6697/#supybot-fr).

==> limnoria_2020.01.31.orig.tar.gz: limnoria-2020.01.31/README.md <==
Supybot is a robust (it doesn't crash), user friendly (it's easy to
configure) and programmer friendly (plugins are *extremely* easy to
write) Python IRC bot.  It aims to be an adequate replacement for most
existing IRC bots.  It includes a very flexible and powerful ACL system
for controlling access to commands, as well as more than 50 builtin plugins
providing around 400 actual commands.

Limnoria is the project which continues development of Supybot since 2010.

# Build status

Master branch: [![Build Status (master branch)](https://travis-ci.org/ProgVal/Limnoria.png?branch=master)](https://travis-ci.org/ProgVal/Limnoria)

Testing branch: [![Build Status (testing branch)](https://travis-ci.org/ProgVal/Limnoria.png?branch=testing)](https://travis-ci.org/ProgVal/Limnoria)

Limnoria supports CPython 3.4, 3.5, 3.6, 3.7, nightly;
and Pypy 3.

# Support

## Documentation

If this is your first install, there is an [install guide](http://doc.supybot.aperio.fr/en/latest/use/install.html).
You will probably be pointed to it if you ask on IRC how to install
Limnoria.
TL;DR version:

```
sudo apt-get install python3 python3-pip python3-wheel
pip3 install --user limnoria
# You might need to add $HOME/.local/bin to your PATH
supybot-wizard
```

There is extensive documentation at [doc.supybot.aperio.fr] and at
[Gribble wiki]. We took the time to write it; you should take the time to
read it.

[doc.supybot.aperio.fr]:http://doc.supybot.aperio.fr/
[Gribble wiki]:https://sourceforge.net/p/gribble/wiki/Main_Page/

## IRC channels

### In English

If you have any trouble, feel free to swing by [#supybot and #limnoria](ircs://chat.freenode.net:6697/#supybot,#limnoria) on
[freenode](https://freenode.net/) or [#supybot](ircs://irc.oftc.net:6697/#supybot) at [OFTC](http://oftc.net/) (we have a Limnoria there relaying,
so either network works) and ask questions.  We'll be happy to help
wherever we can.  And by all means, if you find anything hard to
understand or think you know of a better way to do something,
*please* post it on the [issue tracker] so we can improve the bot!

[issue tracker]:https://github.com/ProgVal/Limnoria/issues

### In Other languages

Only in French at the moment, located at [#supybot-fr on freenode](ircs://chat.freenode.net:6697/#supybot-fr).
